@@ -151,6 +151,8 @@ setMethod("export", c("List", "BigWigFile"),
             con <- path.expand(path(con))
             if (!isTRUEorFALSE(compress))
               stop("'compress' must be TRUE or FALSE")
+            if (is.null(names(object)))
+                stop("'object' must have names")
             seqlengths <- elementNROWS(object)
             sectionPtr <- NULL # keep adding to the same linked list
             on.exit(.Call(BWGSectionList_cleanup, sectionPtr))
@@ -207,14 +209,9 @@ setMethod("import.bw", "ANY",
 
 setMethod("import", "BigWigFile",
           function(con, format, text, selection = BigWigSelection(which, ...),
-                   which = con, asRle = FALSE,
+                   which = con,
                    as = c("GRanges", "RleList", "NumericList"), ...)
           {
-            if (asRle) {
-              warning("'asRle' argument has been deprecated, ",
-                      "use 'as=\"RleList\"' instead")
-              as <- "RleList"
-            }
             if (!missing(format))
               checkArgFormat(con, format)
             as <- match.arg(as)
