@@ -103,7 +103,7 @@ setMethod("export", c("GenomicRanges", "GFFFile"),
             if (!append) {
               cat("", file = con) # clear any existing file
               gffComment(con, "gff-version", version)
-              sourceVersion <- try(package.version(source), TRUE)
+              sourceVersion <- try(packageVersion(source), TRUE)
               if (!inherits(sourceVersion, "try-error"))
                 gffComment(con, "source-version", source, sourceVersion)
               gffComment(con, "date", base::format(Sys.time(), "%Y-%m-%d"))
@@ -122,14 +122,15 @@ setMethod("export", c("GenomicRanges", "GFFFile"),
               seqname <- urlEncode(seqname, "a-zA-Z0-9.:^*$@!+_?|-")
             if (!is.null(object$source) && missing(source))
               source <- object$source
+            else source <- rep(source, length(object))
             if (version == "3")
               source <- urlEncode(source, "\t\n\r;=%&,", FALSE)
             feature <- object$type
             if (is.null(feature))
-              feature <- "sequence_feature"
+              feature <- rep("sequence_feature", length(object))
             score <- score(object)
             if (is.null(score)) {
-              score <- NA
+              score <- rep(NA_real_, length(object))
             } else {
               if (!("score" %in% colnames(mcols(object))))
                 ## avoid outputting as attribute
@@ -137,10 +138,11 @@ setMethod("export", c("GenomicRanges", "GFFFile"),
             }
             strand <- strand(object)
             if (is.null(strand))
-              strand <- NA
+                strand <- rep(strand(NA_character_), length(object))
+            strand[strand == "*"] <- NA_integer_
             frame <- object$phase
             if (is.null(frame))
-              frame <- NA
+              frame <- rep(NA_integer_, length(object))
             
             table <- data.frame(seqname, source, feature, start(object),
                                 end(object), score, strand, frame)
@@ -341,15 +343,16 @@ setMethod("asGFF", "GRangesList",
             values(children)$Parent <- rep.int(parentIds, elementNROWS(x))
             allColumns <- union(colnames(values(parents)),
                                 colnames(values(children)))
-            rectifyDataFrame <- function(x) {
-              x[setdiff(allColumns, colnames(x))] <- DataFrame(NA)
-              x[allColumns]
-            }
-            values(children) <- rectifyDataFrame(values(children))
-            values(parents) <- rectifyDataFrame(values(parents))
+            values(children) <- rectifyDataFrame(values(children), allColumns)
+            values(parents) <- rectifyDataFrame(values(parents), allColumns)
             c(parents, children)
           })
 
+rectifyDataFrame <- function(x, allColumns) {
+    x[setdiff(allColumns, colnames(x))] <- DataFrame(NA)
+    x[allColumns]
+}
+
 ### FIXME: We wrote this but never tested it, and it is not yet
 ### used. People should use GFF3 instead of this.
 ###
@@ -381,15 +384,17 @@ setMethod("asGTF", "GRangesList",
                       ans$gene_id <- ""
                   }
                   if (is.null(ans$transcript_id)) {
-                      ans$transcript_id <- tx_id[togroup(f)]
+                      ans$transcript_id <- tx_ids[togroup(f)]
                   }
                   ans
               }
-              start_codon_tx <- pmapFromTranscripts(IRanges(1L, 3L), x)
+              start_codon_tx <-
+                  GenomicFeatures::pmapFromTranscripts(IRanges(1L, 3L), x)
               start_codon <- processFeatures(start_codon_tx)
               mcols(start_codon)$type <- "start_codon"
               stop_ranges <- IRanges(end=sum(width(x)), width=3L)
-              stop_codon_tx <- pmapFromTranscripts(stop_ranges, x)
+              stop_codon_tx <-
+                  GenomicFeatures::pmapFromTranscripts(stop_ranges, x)
               stop_codon <- processFeatures(stop_codon_tx)
               mcols(stop_codon)$type <- "stop_codon"
               codons <- c(start_codon, stop_codon)
